@@ -3,6 +3,11 @@ use std::path::PathBuf;
 use rscript::Hook;
 use serde::{Deserialize, Serialize};
 
+// Reexport crossterm event types
+pub mod event {
+    pub use crossterm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
+}
+
 macro_rules! hookit {
     (Hook => $hook: ident,
      Input => ($($input: ty $(,)?)*),
@@ -19,10 +24,15 @@ macro_rules! hookit {
 
 hookit!(
 Hook => InputEvent,
-Input => (GlobalVariables, crossterm::event::Event),
+Input => (GlobalVariables, event::Event),
 Output => Option<Command>
 );
 hookit!(
+Hook => OutputEvent,
+Input => (GlobalVariables, String),
+Output => Option<String>
+);
+hookit!(
 Hook => Shutdown,
 Input => (GlobalVariables),
 Output => Option<Command>
